function [module] = combineSubgraphs(patterns)
%COMBINESUBGRAPHS merges all closed frequent subgraphs in a single co-module.
%
%   [MODULE] = COMBINESUBGRAPHS(PATTERNS) merges all closed frequent subgraphs
%   in the structure PATTERNS and return a single module in the structure
%   MODULE.
%
%
% References:
% [1] Bahadir Ozdemir, Wael Abd-Almageed, Stephanie Roessler, Xin Wei Wang.
%     "iSubgraph: Integrative Genomics for Subgroup Discovery in
%     Hepatocellular Carcinoma using Graph Mining and Mixture Models",
%     PLoS ONE (under review).
% [2] Mathias Fiedler and Christian Borgelt. "Support Computation for Mining
%     Frequent Subgraphs in a Single Graph", Proc. 5th Int. Workshop on Mining
%     and Learning with Graphs (MLG 2007, Florence, Italy).
%
%
%
%   Copyright (C) 2013 Bahadir Ozdemir
%
%   This file is part of iSubgraph.
%
%   iSubgraph is free software: you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation, either version 3 of the License, or
%   (at your option) any later version.
%
%    iSubgraph is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.


% create module structure
module = patterns(1);
for i = 1:length(patterns)
    module.gene_up = union(module.gene_up, patterns(i).gene_up);
    module.gene_down = union(module.gene_down, patterns(i).gene_down);
    module.miRNA_up = union(module.miRNA_up, patterns(i).miRNA_up);
    module.miRNA_down = union(module.miRNA_down, patterns(i).miRNA_down);
end

% merge nodes
if isempty(module.gene_up)
    module.gene_up = [];
else
    module.gene_up = module.gene_up(:);
end

if isempty(module.gene_down)
    module.gene_down = [];
else
    module.gene_down = module.gene_down(:);
end

if isempty(module.miRNA_up)
    module.miRNA_up = [];
else
    module.miRNA_up = module.miRNA_up(:);
end

if isempty(module.miRNA_down)
    module.miRNA_down = [];
else
    module.miRNA_down = module.miRNA_down(:);
end
module.freq = NaN;
module.size = length(module.gene_up) + length(module.gene_down) + ...
    length(module.miRNA_up) + length(module.miRNA_down);
